.. _supported-versions:

Supported versions
==================

``django-guardian`` supports Python 2.6/2.7 and Django 1.2+. Also, we support
``django-grappelli`` 2.3.5.

Rules
-----

1. We would support both Python 2.7 and Python 2.6 (until Django drops support
   for 2.6, if ever).
2. We would support **two latest Django stable versions**. In example: once
   Django 1.4 would become final, we are dropping support for Django 1.2 as
   two last stable versions would be 1.3 and 1.4.
3. Support for ``django-grappelli`` is somewhat experimental. Nevertheless,
   our intention is **to support django-grappelli last stable version**.

